complete -c yazi -l cwd-file -d 'Write the cwd on exit to this file' -r -F
complete -c yazi -l chooser-file -d 'Write the selected files to this file on open fired' -r -F
complete -c yazi -l client-id -d 'Use the specified client ID, must be a globally unique number' -r
complete -c yazi -l local-events -d 'Report the specified local events to stdout' -r
complete -c yazi -l remote-events -d 'Report the specified remote events to stdout' -r
complete -c yazi -s V -l version -d 'Print version'
complete -c yazi -s h -l help -d 'Print help'
